"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const prettyjson = require("prettyjson");
const configQuestions = require("../questions/config");
const Preferences_1 = require("../utilities/Preferences");
const fs = require("fs");
const os_1 = require("os");
const path = require("path");
function getConfig(options) {
    let app = options.app;
    let user = options.user;
    function preferenceExists(identifier) {
        const homeDir = os_1.homedir();
        const dirPath = path.join(homeDir, '.config', 'composer');
        const filePath = path.join(dirPath, identifier + '.pref');
        return fs.existsSync(filePath);
    }
    // if program was called with no options, show help.
    if (!app && !user) {
        const savedConfig = preferenceExists('cmp-chart')
            ? Preferences_1.Preferences('cmp-chart')
            : Preferences_1.Preferences('zd-chart', 'zoomdata');
        if (Object.keys(savedConfig).length === 0) {
            console.log('A configuration file was not found. \n' +
                'Please execute the command with the --user and -app options');
        }
        else {
            app = savedConfig.application;
            user = {
                password: savedConfig.password,
                username: savedConfig.username,
            };
        }
    }
    else if (!app || !user) {
        // if program was called with either option undefined
        const savedConfig = preferenceExists('cmp-chart')
            ? Preferences_1.Preferences('cmp-chart')
            : Preferences_1.Preferences('zd-chart', 'zoomdata');
        if (Object.keys(savedConfig).length === 0) {
            console.log('A configuration file was not found. \n' +
                'Please execute the command with the --user and -app options');
        }
        else {
            app = app || savedConfig.application;
            user = user || {
                password: savedConfig.password,
                username: savedConfig.username,
            };
        }
    }
    return {
        application: app,
        password: user && user.password,
        username: user && user.username,
    };
}
exports.getConfig = getConfig;
function config() {
    return configQuestions.prompt().catch((error) => {
        console.log(prettyjson.render(error));
        return Promise.reject(error);
    });
}
exports.config = config;
