"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs_1 = require("fs");
const os_1 = require("os");
const mkdirp = require("mkdirp");
const utilities_1 = require("../utilities");
const packageJson = require('../templates/package.json');
const singleGroupVisualizationJson = require('../templates/single_group_visualization.json');
const multiGroupVisualizationJson = require('../templates/multi_group_visualization.json');
const rawVisualizationJson = require('../templates/raw_visualization.json');
function init(chartPath, type) {
    const root = path.resolve(chartPath);
    const name = path.basename(chartPath);
    mkdirp.sync(root);
    fs_1.writeFileSync(root + '/webpack.config.js', getWebpackConfigJs());
    fs_1.writeFileSync(root + '/package.json', getPackageJson(name));
    utilities_1.writeVisualizationConfig(root, getVisualizationJson(name, type));
    fs_1.mkdirSync(root + '/src');
    fs_1.writeFileSync(root + '/src/index.js', getSrcIndexJs(type));
    fs_1.writeFileSync(root + '/src/index.css', getSrcIndexCss());
}
exports.init = init;
function getWebpackConfigJs() {
    return fs_1.readFileSync(path.resolve(__dirname, '../templates/webpack.config.js'));
}
function getPackageJson(name) {
    const json = Object.assign({ name }, packageJson);
    return JSON.stringify(json, null, 2) + os_1.EOL;
}
function getVisualizationJson(name, type) {
    let template;
    switch (type) {
        case 'single-group':
            template = singleGroupVisualizationJson;
            break;
        case 'multi-group':
            template = multiGroupVisualizationJson;
            break;
        case 'raw':
            template = rawVisualizationJson;
            break;
    }
    return Object.assign({ name }, template);
}
function getSrcIndexJs(type) {
    let templateFileName;
    switch (type) {
        case 'single-group':
            templateFileName = 'single_group_index';
            break;
        case 'multi-group':
            templateFileName = 'multi_group_index';
            break;
        case 'raw':
            templateFileName = 'raw_index';
            break;
    }
    return fs_1.readFileSync(path.resolve(__dirname, `../templates/${templateFileName}.js`));
}
function getSrcIndexCss() {
    return fs_1.readFileSync(path.resolve(__dirname, '../templates/index.css'));
}
