#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const program = require("commander");
const ora = require("ora");
const prettyjson = require("prettyjson");
const requests_1 = require("./requests");
const config_1 = require("./commands/config");
const utilities_1 = require("./utilities");
program
    .description('Import a custom chart to the Composer server')
    .arguments('<name> <filepath>')
    .option('-a, --app [URL]', 'Specify the Composer application server URL (e.g. https://myserver/composer)', utilities_1.parseUrl)
    .option('-u, --user [user:password]', 'Specify the user name and password to use for server authentication.', utilities_1.parseCredentials)
    .parse(process.argv);
const config = config_1.getConfig(program.opts());
if (!config.application || config.application instanceof Error || !config.username) {
    program.help();
    process.exit(1);
}
if (program.args.length < 2) {
    console.log('Invalid number of arguments. Please provide the name and filepath of the chart or library you want to add');
    program.help();
    process.exit(1);
}
else {
    const objectName = program.args[0];
    const filepath = program.args[1];
    const spinner = ora(`Adding chart: ${objectName}`).start();
    requests_1.visualizations
        .importPkg(objectName, fs.createReadStream(filepath), config)
        .then(() => spinner.succeed())
        .catch((error) => {
        spinner.fail();
        console.log(prettyjson.render(error));
        process.exit(1);
    });
}
