#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const program = require("commander");
const init_1 = require("./commands/init");
const ora = require("ora");
const prettyjson = require("prettyjson");
const defaultChartType = 'single-group';
const availableChartTypes = ['single-group', 'multi-group', 'raw'];
program
    .description('Bootstrap a new chart')
    .arguments('<path>')
    .option('-t, --type <type>', `Specify the chart type. Valid options: ${availableChartTypes.join(', ')}`, (type) => {
    if (!availableChartTypes.includes(type)) {
        console.log(`Invalid chart type: ${type}. Please enter a valid type.`);
        program.help();
        process.exit(1);
    }
    else {
        return type;
    }
}, defaultChartType)
    .parse(process.argv);
if (program.args.length !== 1) {
    console.log('Invalid number of arguments. Please provide the path where you want the chart to be bootstrapped');
    program.help();
    process.exit(1);
}
else {
    const { type } = program.opts();
    const spinner = ora('Bootstrapping chart').start();
    try {
        init_1.init(program.args[0], type);
        spinner.succeed();
    }
    catch (e) {
        spinner.fail();
        console.log(prettyjson.render(e));
        process.exit(1);
    }
}
