#!/usr/bin/env node
"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
const program = require("commander");
const ora = require("ora");
const prettyjson = require("prettyjson");
const config_1 = require("./commands/config");
const push_1 = require("./commands/push");
const utilities_1 = require("./utilities");
program
    .description('Push the current state of the chart to the Composer server')
    .option('-a, --app [URL]', 'Specify the Composer application server URL (e.g. https://myserver/composer)', utilities_1.parseUrl)
    .option('-d, --dir [path/to/source/files]', 'Directory used to look for the chart to push.')
    .option('-u, --user [user:password]', 'Specify the user name and password to use for server authentication.', utilities_1.parseCredentials)
    .parse(process.argv);
const _a = program.opts(), { dir } = _a, options = __rest(_a, ["dir"]);
const config = config_1.getConfig(options);
if (!config.application || config.application instanceof Error || !config.username) {
    program.help();
    process.exit(1);
}
else {
    const spinner = ora('Reading configuration').start();
    const log = (text) => {
        spinner.text = text;
    };
    push_1.push(dir || process.cwd(), config, log)
        .then(() => {
        spinner.succeed();
    })
        .catch((error) => {
        spinner.fail();
        console.log(prettyjson.render(error));
    });
}
