"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const inquirer = require("inquirer");
const os_1 = require("os");
const path = require("path");
const shelljs_1 = require("shelljs");
const Preferences_1 = require("../../utilities/Preferences");
const questions = [
    {
        message: 'Enter the URL for the Composer server (e.g. https://myserver/composer)',
        name: 'application',
        type: 'input',
        validate(value) {
            // TODO: Refactor with a better URL validator
            if (value.length > 0) {
                return true;
            }
            else {
                return 'Please enter a valid server URL';
            }
        },
    },
    {
        message: 'Enter a username to use for server authentication:',
        name: 'username',
        type: 'input',
        validate(value) {
            if (value.length > 0) {
                return true;
            }
            else {
                return 'Please enter a valid username';
            }
        },
    },
    {
        mask: '*',
        message: "Enter the username's password ",
        name: 'password',
        type: 'password',
        validate(value) {
            if (value.length > 0) {
                return true;
            }
            else {
                return 'Please enter a valid password';
            }
        },
    },
];
function answerHandler(answers) {
    const configId = 'cmp-chart';
    const identifier = configId.replace(/[\/?<>\\:*|" ]/g, '.').replace(/\.+/g, '.');
    const homeDir = os_1.homedir();
    const dirPath = path.join(homeDir, '.config', 'composer');
    const filePath = path.join(dirPath, identifier + '.pref');
    //noinspection ReservedWordAsName
    const confirm = [
        {
            default: false,
            message: `Store the above configuration in ${filePath}?:`,
            name: 'configSave',
            type: 'confirm',
        },
    ];
    inquirer.prompt(confirm).then((confirmAnswers) => {
        if (confirmAnswers.configSave) {
            try {
                if (shelljs_1.test('-e', filePath)) {
                    fs.unlinkSync(filePath);
                }
            }
            catch (e) {
                throw e;
            }
            Preferences_1.Preferences(configId, '', answers);
        }
    });
}
function prompt() {
    return inquirer.prompt(questions).then(answerHandler);
}
exports.prompt = prompt;
