"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer = require("inquirer");
const attributeQuestions = require("./attribute");
const boolQuestions = require("./bool");
const colorQuestions = require("./color");
const boxPlotQuestions = require("./box-plot-metric");
const floatQuestions = require("./float");
const groupQuestions = require("./group");
const histogramGroupQuestion = require("./histogram-group");
const integerQuestions = require("./integer");
const metricQuestions = require("./metric");
const multiGroupQuestions = require("./multi-group");
const multiMetricQuestions = require("./multi-metric");
const multiListQuestion = require("./multilist");
const singleListQuestions = require("./singlelist");
const stringQuestions = require("./string");
const textQuestions = require("./text");
const ungroupedQuestions = require("./ungrouped");
const ungroupedListQuestions = require("./ungroupedList");
function prompt(visualizationVariables) {
    return __awaiter(this, void 0, void 0, function* () {
        const groupedVariableTypeOptions = ['group', 'multi-group', 'histogram-group'];
        const metricVariableTypeOptions = ['metric', 'multi-metric', 'box-plot-metric'];
        const ungroupedVariableTypeOptions = ['ungrouped', 'ungroupedList'];
        const constantVariableTypeOptions = [
            'string',
            'text',
            'integer',
            'float',
            'bool',
            'color',
            'attribute',
            'singlelist',
            'multilist',
        ];
        const containsUngroupedVariable = visualizationVariables.some((variable) => ungroupedVariableTypeOptions.includes(variable.type));
        const questions = [
            {
                message: 'Select the type of the variable you would like to add:',
                name: 'variableType',
                type: 'list',
                choices: containsUngroupedVariable
                    ? [new inquirer.Separator(' = Constant Variables: = '), ...constantVariableTypeOptions]
                    : [
                        new inquirer.Separator(' = Query Variables: = '),
                        ...groupedVariableTypeOptions,
                        ...ungroupedVariableTypeOptions,
                        ...metricVariableTypeOptions,
                        new inquirer.Separator(' = Constant Variables: = '),
                        ...constantVariableTypeOptions,
                    ],
            },
            {
                message: 'Enter a name for the new variable:',
                name: 'variableName',
                type: 'input',
            },
            {
                message: 'Enter a description for the variable:',
                name: 'variableDescription',
                type: 'input',
            },
        ];
        const answers = yield inquirer.prompt(questions);
        const variable = yield createVariable(answers);
        return visualizationVariables.concat(variable);
    });
}
exports.prompt = prompt;
function createVariable({ variableType, variableName, variableDescription }) {
    const variableOpts = {
        colorMetric: false,
        colorNumb: 0,
        defaultValue: '',
        descr: variableDescription,
        name: variableName,
        required: false,
    };
    switch (variableType) {
        case 'group':
            return groupQuestions.prompt(variableOpts);
        case 'multi-group':
            return multiGroupQuestions.prompt(variableOpts);
        case 'histogram-group':
            return Promise.resolve(histogramGroupQuestion.prompt(variableOpts));
        case 'metric':
            return metricQuestions.prompt(variableOpts);
        case 'multi-metric':
            return multiMetricQuestions.prompt(variableOpts);
        case 'box-plot-metric':
            return Promise.resolve(boxPlotQuestions.prompt(variableOpts));
        case 'ungrouped':
            return ungroupedQuestions.prompt(variableOpts);
        case 'ungroupedList':
            return Promise.resolve(ungroupedListQuestions.prompt(variableOpts));
        case 'attribute':
            return attributeQuestions.prompt(variableOpts);
        case 'singlelist':
            return singleListQuestions.prompt(variableOpts);
        case 'multilist':
            return multiListQuestion.prompt(variableOpts);
        case 'string':
            return stringQuestions.prompt(variableOpts);
        case 'text':
            return textQuestions.prompt(variableOpts);
        case 'bool':
            return boolQuestions.prompt(variableOpts);
        case 'float':
            return floatQuestions.prompt(variableOpts);
        case 'integer':
            return integerQuestions.prompt(variableOpts);
        case 'color': {
            return colorQuestions.prompt(variableOpts);
        }
    }
}
