"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer = require("inquirer");
const multi_group_1 = require("../common/multi-group");
function prompt(varOpts) {
    return __awaiter(this, void 0, void 0, function* () {
        const answers = yield inquirer.prompt(multi_group_1.questions);
        const groupLevels = parseInt(answers.groupLevels, 10);
        const levelQuestions = [];
        for (let i = 1; i <= groupLevels; i++) {
            levelQuestions.push({
                message: `Enter a name to identify group level ${i}:`,
                name: `groupLevelName.${i}`,
                type: 'input',
            });
            const choices = ['NONE', 'ATTRIBUTE', 'TIME'];
            levelQuestions.push({
                choices,
                message: `Select one or more field types allowed when configuring group level ${i}:`,
                name: `groupType.${i}`,
                type: 'checkbox',
                validate: (value) => {
                    return value.length > 0;
                },
            });
        }
        levelQuestions.push({
            default: false,
            message: 'Will one of the levels drive color in your chart?:',
            name: 'colorFlag',
            type: 'confirm',
        });
        const levelAnswers = yield inquirer.prompt(levelQuestions);
        let colorLevel;
        if (levelAnswers.colorFlag) {
            const colorQuestions = [
                {
                    message: 'Which level should drive color for this chart?:',
                    name: 'colorLevel',
                    type: 'input',
                    validate: (value) => typeof parseInt(value, 10) === 'number' &&
                        parseInt(value, 10) > 0 &&
                        parseInt(value, 10) <= groupLevels,
                },
            ];
            const colorAnswers = yield inquirer.prompt(colorQuestions);
            colorLevel = parseInt(colorAnswers.colorLevel, 10);
        }
        const groupNames = [];
        const groupTypes = [];
        for (let i = 1; i <= groupLevels; i++) {
            groupNames.push(levelAnswers.groupLevelName[i]);
            groupTypes.push(levelAnswers.groupType[i].join(' '));
        }
        const variableDef = Object.assign({}, varOpts, {
            attributeType: ['ATTRIBUTE', 'TIME'],
            config: {
                groupLevel: groupLevels,
                groupLimits: [50, 20],
                groupNames,
                groupTypes,
            },
            type: 'multi-group',
        });
        if (colorLevel) {
            const colorConfig = {
                autoShowColorLegend: false,
                colorGroupIndex: colorLevel - 1,
                groupColorSet: 'ZoomPalette',
            };
            Object.assign(variableDef.config, colorConfig);
        }
        return variableDef;
    });
}
exports.prompt = prompt;
