"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer = require("inquirer");
const multilist_1 = require("../../common/multilist");
function prompt(variable) {
    return __awaiter(this, void 0, void 0, function* () {
        multilist_1.questions[0].default =
            variable.attributeType && variable.attributeType.indexOf('ATTRIBUTE') >= 0 ? 'ATTRIBUTE' : 'CUSTOM';
        const { listType } = yield inquirer.prompt(multilist_1.questions);
        if (listType === 'CUSTOM') {
            const customQuestion = [
                {
                    message: 'Enter the number of items in the list:',
                    name: 'itemNumber',
                    type: 'input',
                    validate: (value) => typeof parseInt(value, 10) === 'number' && parseInt(value, 10) >= 1,
                },
            ];
            const customAnswers = yield inquirer.prompt(customQuestion);
            const itemNumber = parseInt(customAnswers.itemNumber, 10);
            const itemQuestions = [];
            for (let i = 1; i <= itemNumber; i++) {
                itemQuestions.push({
                    message: `Enter a name to identify item ${i}:`,
                    name: `itemName.${i}`,
                    type: 'input',
                });
            }
            const { itemName } = yield inquirer.prompt(itemQuestions);
            const itemNames = [];
            for (let i = 1; i <= itemNumber; i++) {
                itemNames.push(itemName[i]);
            }
            const defaultQuestion = [
                {
                    choices: itemNames,
                    message: 'Select a default value(s) from the list:',
                    name: 'defaultValue',
                    type: 'checkbox',
                    validate: (value) => value.length > 0,
                },
            ];
            const { defaultValue } = yield inquirer.prompt(defaultQuestion);
            const newVariable = Object.assign({}, variable, { defaultValue: defaultValue.map((value) => ({ name: value })), values: itemNames });
            delete newVariable.attributeType;
            return newVariable;
        }
        else {
            const newVariable = Object.assign({}, variable, { attributeType: ['ATTRIBUTE'], defaultValue: [] });
            delete newVariable.values;
            return newVariable;
        }
    });
}
exports.prompt = prompt;
