"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer = require("inquirer");
const utilities_1 = require("../../../../utilities");
const configuration_1 = require("./configuration");
const descriptionQuestions = require("./description");
const nameQuestions = require("./name");
function prompt(visualizationVariables) {
    return __awaiter(this, void 0, void 0, function* () {
        const tableRows = utilities_1.getVariablesTableRows(visualizationVariables);
        const questions = [
            {
                choices: [
                    new inquirer.Separator(tableRows[0]),
                    new inquirer.Separator('-'.repeat(tableRows[0].length)),
                    ...tableRows.slice(1).map((row, index) => ({
                        name: row,
                        short: visualizationVariables[index].name,
                        value: visualizationVariables[index],
                    })),
                ],
                message: 'Select the variable you would like to edit:',
                name: 'variable',
                type: 'list',
            },
        ];
        const { variable } = yield inquirer.prompt(questions);
        if (isConfigurableVariable(variable)) {
            Object.assign(variable, yield editWithConfiguration(variable));
        }
        else {
            Object.assign(variable, yield edit(variable));
        }
        return visualizationVariables;
    });
}
exports.prompt = prompt;
function edit(variable) {
    return __awaiter(this, void 0, void 0, function* () {
        const choices = ['Name', 'Description'];
        const editQuestions = [
            {
                choices,
                message: 'What would you like to edit:',
                name: 'editOption',
                type: 'list',
            },
        ];
        const { editOption } = yield inquirer.prompt(editQuestions);
        switch (editOption) {
            case 'Name':
                return Object.assign({}, variable, { name: yield nameQuestions.prompt(variable) });
            case 'Description':
                return Object.assign({}, variable, { descr: yield descriptionQuestions.prompt(variable) });
        }
    });
}
function editWithConfiguration(variable) {
    return __awaiter(this, void 0, void 0, function* () {
        const choices = ['Name', 'Description', 'Configuration'];
        const editQuestions = [
            {
                choices,
                message: 'What would you like to edit:',
                name: 'editOption',
                type: 'list',
            },
        ];
        const { editOption } = yield inquirer.prompt(editQuestions);
        switch (editOption) {
            case 'Name':
                return Object.assign({}, variable, { name: yield nameQuestions.prompt(variable) });
            case 'Description':
                return Object.assign({}, variable, { descr: yield descriptionQuestions.prompt(variable) });
            case 'Configuration':
                return configuration_1.prompt(variable);
        }
    });
}
function isConfigurableVariable(variable) {
    switch (variable.type) {
        case 'box-plot-metric':
        case 'histogram-group':
        case 'ungrouped':
            return false;
        default:
            return true;
    }
}
