"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const inquirer = require("inquirer");
const lodash_1 = require("lodash");
const ora = require("ora");
const prettyjson = require("prettyjson");
const requests_1 = require("../requests");
const selectQuestions = require("./select");
function answerHandler(visualization, serverConfig) {
    return requests_1.dashboards
        .get(serverConfig, {
        visualizationId: visualization.id,
        fields: 'name',
    })
        .then((dbs) => {
        if (dbs.bookmarksMap.length > 0) {
            console.log(`${chalk_1.default.red(visualization.name)} cannot be deleted because it is being used in the dashboards below. \n` +
                `You will need to remove all instances of ${chalk_1.default.red(visualization.name)} from each dashboard before it can be deleted.`);
            console.log(chalk_1.default.yellow(prettyjson.render(lodash_1.sortBy(dbs.bookmarksMap.map((bookmark) => bookmark.name), (bookmarkName) => bookmarkName.toLowerCase()))));
            return Promise.resolve();
        }
        else {
            //noinspection ReservedWordAsName
            const confirm = [
                {
                    default: false,
                    message: 'Are you sure you would like to remove this chart from the server?:',
                    name: 'chartDelete',
                    type: 'confirm',
                },
            ];
            return inquirer.prompt(confirm).then((confirmAnswers) => {
                if (confirmAnswers.chartDelete) {
                    const spinner = ora(`Removing chart: ${visualization.name} from the server`).start();
                    return requests_1.visualizations
                        .remove(visualization.id, serverConfig)
                        .then(() => {
                        spinner.succeed();
                        return Promise.resolve();
                    })
                        .catch((error) => {
                        spinner.fail();
                        return Promise.reject(error);
                    });
                }
                else {
                    return Promise.resolve();
                }
            });
        }
    });
}
function prompt(serverConfig) {
    return __awaiter(this, void 0, void 0, function* () {
        return selectQuestions.prompt(serverConfig).then((visualization) => answerHandler(visualization, serverConfig));
    });
}
exports.prompt = prompt;
