"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fuzzy = require("fuzzy");
const inquirer = require("inquirer");
const lodash_1 = require("lodash");
const ora = require("ora");
const requests_1 = require("../requests");
inquirer.registerPrompt('autocomplete', require('inquirer-autocomplete-prompt'));
// TODO Change questions type once ChoiceOption has been fixed
const questions = [
    {
        message: 'Select a custom chart:',
        name: 'chart',
        type: 'autocomplete',
    },
];
function answerHandler(answers) {
    return answers.chart;
}
function prompt(serverConfig) {
    const spinner = ora('Fetching custom charts').start();
    return requests_1.visualizations
        .getCustom(serverConfig)
        .then((customVisualizations) => {
        spinner.succeed();
        questions[0].source = searchCustomCharts;
        function searchCustomCharts(answers, input) {
            input = input || '';
            return new Promise((resolve) => {
                const fuzzyResult = fuzzy.filter(input, lodash_1.sortBy(customVisualizations, (customVis) => customVis.name.toLowerCase()), { extract: (el) => el.name });
                resolve(fuzzyResult.map((el) => ({
                    name: el.string,
                    value: el.original,
                })));
            });
        }
        return inquirer.prompt(questions).then((answers) => answerHandler(answers));
    })
        .catch((error) => {
        spinner.fail();
        return Promise.reject(error);
    });
}
exports.prompt = prompt;
