"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const contentType = require("content-type");
const requestPromise = require("request-promise-native");
const utilities_1 = require("../utilities");
function send(requestOptions) {
    const defaultOptions = {
        simple: true,
        strictSSL: false,
        transform: autoParse,
        transform2xxOnly: true,
    };
    const options = Object.assign({}, defaultOptions, requestOptions);
    return requestPromise(options);
}
exports.send = send;
function autoParse(body, response) {
    if (response.request.method === 'POST') {
        if (contentType.parse(response.headers['content-type']).type === 'application/vnd.composer.v3+json' ||
            contentType.parse(response.headers['content-type']).type === 'application/json') {
            const parsedJSON = utilities_1.parseJSON(body);
            if (parsedJSON instanceof Error) {
                /* Don't through Error. Zoomdata will sometime return plain text in responses
         with content-type = application/vnd.composer.v3+json'. Refer to ticket: ZP-5063 */
                return body;
            }
            else {
                return parsedJSON;
            }
        }
    }
    if (response.request.method === 'GET') {
        if (contentType.parse(response.headers['content-type']).type === 'application/vnd.composer.v3+json' ||
            contentType.parse(response.headers['content-type']).type === 'application/json') {
            const parsedJSON = utilities_1.parseJSON(body);
            if (parsedJSON instanceof Error) {
                throw parsedJSON;
            }
            else {
                return parsedJSON;
            }
        }
        else if (contentType.parse(response.headers['content-type']).type === 'application/octet-stream') {
            return body;
        }
        else {
            throw new Error('Invalid content type received in response');
        }
    }
}
