"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const send_1 = require("./send");
function create(body, serverConfig) {
    const { application, username, password } = serverConfig;
    const url = `${application}/api/visual-types`;
    const requestOptions = {
        auth: { username, password },
        body,
        headers: { 'content-type': 'application/vnd.composer.v3+json' },
        method: 'POST',
        url,
    };
    return send_1.send(requestOptions);
}
exports.create = create;
function get(serverConfig, queryOptions) {
    const { application, username, password } = serverConfig;
    const url = `${application}/api/visual-types`;
    const requestOptions = {
        auth: { username, password },
        headers: { 'content-type': 'application/vnd.composer.v3+json' },
        qs: queryOptions,
        url,
    };
    return send_1.send(requestOptions).then((result) => result.content);
}
exports.get = get;
function getCustom(serverConfig) {
    return get(serverConfig, { builtIn: false });
}
exports.getCustom = getCustom;
function getByName(name, serverConfig) {
    return __awaiter(this, void 0, void 0, function* () {
        const visualizations = yield get(serverConfig, { name });
        if (visualizations.length === 0) {
            return null;
        }
        else {
            return visualizations[0];
        }
    });
}
exports.getByName = getByName;
function importPkg(objectName, fileData, serverConfig) {
    const { application, username, password } = serverConfig;
    const url = `${application}/api/visual-types/import`;
    const requestOptions = {
        auth: { username, password },
        formData: {
            file: fileData,
            visName: objectName,
        },
        headers: { 'content-type': 'application/vnd.composer.v3+json' },
        method: 'POST',
        url,
    };
    return send_1.send(requestOptions);
}
exports.importPkg = importPkg;
function update(visualizationId, body, serverConfig) {
    const { application, username, password } = serverConfig;
    const url = `${application}/api/visual-types/${visualizationId}`;
    const requestOptions = {
        auth: { username, password },
        body,
        headers: { 'content-type': 'application/vnd.composer.v3+json' },
        method: 'PUT',
        url,
    };
    return send_1.send(requestOptions);
}
exports.update = update;
function remove(visualizationId, serverConfig) {
    const { application, username, password } = serverConfig;
    const url = `${application}/api/visual-types/${visualizationId}`;
    const requestOptions = {
        auth: { username, password },
        headers: { 'content-type': 'application/vnd.composer.v3+json' },
        method: 'DELETE',
        url,
    };
    return send_1.send(requestOptions);
}
exports.remove = remove;
