"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const os_1 = require("os");
const lodash_1 = require("lodash");
const Url = require("url");
const stripAnsi = require("strip-ansi");
const textTable = require("text-table");
function parseJSON(str) {
    return lodash_1.attempt(JSON.parse, str);
}
exports.parseJSON = parseJSON;
function parseCredentials(value) {
    const username = value.split(':')[0];
    const password = value.split(':')[1];
    try {
        if (typeof username !== 'string' || username === '') {
            console.log('The username entered is either empty or in an invalid format.');
            throw new Error('The username entered is either empty or in an invalid format.');
        }
        if (typeof password !== 'string' || password === '') {
            console.log('The password entered is either empty or in an invalid format.');
            throw new Error('The password entered is either empty or in an invalid format.');
        }
    }
    catch (error) {
        return error;
    }
    return { username, password };
}
exports.parseCredentials = parseCredentials;
function parseUrl(value) {
    const urlObj = Url.parse(value);
    try {
        if (urlObj.protocol !== 'http:' && urlObj.protocol !== 'https:') {
            console.log('The URL entered is either empty or in an invalid format.');
            throw new Error('The URL entered is either empty or in an invalid format.');
        }
    }
    catch (error) {
        return error;
    }
    return value;
}
exports.parseUrl = parseUrl;
function readFile(dir, name) {
    return new Promise((resolve, reject) => {
        fs.readFile(path.resolve(dir, name), 'utf8', (err, data) => {
            if (err) {
                reject(err);
            }
            else {
                resolve(data);
            }
        });
    });
}
exports.readFile = readFile;
function readVisualizationConfig(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const visConfigJSON = yield readFile(dir, 'visualization.json');
        return JSON.parse(visConfigJSON);
    });
}
exports.readVisualizationConfig = readVisualizationConfig;
function writeVisualizationConfig(dir, visualizationJson) {
    fs.writeFileSync(path.resolve(dir, 'visualization.json'), JSON.stringify(visualizationJson, null, 2) + os_1.EOL);
}
exports.writeVisualizationConfig = writeVisualizationConfig;
function getVariablesTableRows(variables) {
    const rows = [
        ['Name', 'Type', 'Description'],
        ...variables.map((variable) => [variable.name, variable.type, variable.descr || '']),
    ];
    const options = {
        hsep: '|',
        stringLength: (str) => stripAnsi(str).length,
    };
    return textTable(rows, options).split('\n');
}
exports.getVariablesTableRows = getVariablesTableRows;
